@@ -1,21 +1,11 @@
 # -*- coding: utf-8 -*-
-"""
-    celery.backends.cache
-    ~~~~~~~~~~~~~~~~~~~~~
-
-    Memcache and in-memory cache result backend.
-
-"""
-from __future__ import absolute_import
-
+"""Memcached and in-memory cache result backend."""
+from __future__ import absolute_import, unicode_literals
 import sys
-
-from kombu.utils import cached_property
 from kombu.utils.encoding import bytes_to_str, ensure_bytes
-
+from kombu.utils.objects import cached_property
 from celery.exceptions import ImproperlyConfigured
 from celery.utils.functional import LRUCache
-
 from .base import KeyValueStoreBackend
 
 __all__ = ['CacheBackend']
@@ -25,7 +15,7 @@ _imp = [None]
 PY3 = sys.version_info[0] == 3
 
 REQUIRES_BACKEND = """\
-The memcached backend requires either pylibmc or python-memcached.\
+The Memcached backend requires either pylibmc or python-memcached.\
 """
 
 UNKNOWN_BACKEND = """\
@@ -45,13 +35,15 @@ def import_best_memcache():
                 import memcache  # noqa
             except ImportError:
                 raise ImproperlyConfigured(REQUIRES_BACKEND)
-        if PY3:
+        if PY3:  # pragma: no cover
             memcache_key_t = bytes_to_str
         _imp[0] = (is_pylibmc, memcache, memcache_key_t)
     return _imp[0]
 
 
 def get_best_memcache(*args, **kwargs):
+    # pylint: disable=unpacking-non-sequence
+    #   This is most definitely a sequence, but pylint thinks it's not.
     is_pylibmc, memcache, key_t = import_best_memcache()
     Client = _Client = memcache.Client
 
@@ -73,7 +65,7 @@ class DummyClient(object):
 
     def get_multi(self, keys):
         cache = self.cache
-        return dict((k, cache[k]) for k in keys if k in cache)
+        return {k: cache[k] for k in keys if k in cache}
 
     def set(self, key, value, *args, **kwargs):
         self.cache[key] = value
@@ -84,14 +76,21 @@ class DummyClient(object):
     def incr(self, key, delta=1):
         return self.cache.incr(key, delta)
 
+    def touch(self, key, expire):
+        pass
 
-backends = {'memcache': get_best_memcache,
-            'memcached': get_best_memcache,
-            'pylibmc': get_best_memcache,
-            'memory': lambda: (DummyClient, ensure_bytes)}
+
+backends = {
+    'memcache': get_best_memcache,
+    'memcached': get_best_memcache,
+    'pylibmc': get_best_memcache,
+    'memory': lambda: (DummyClient, ensure_bytes),
+}
 
 
 class CacheBackend(KeyValueStoreBackend):
+    """Cache result backend."""
+
     servers = None
     supports_autoexpire = True
     supports_native_join = True
@@ -100,11 +99,12 @@ class CacheBackend(KeyValueStoreBackend):
     def __init__(self, app, expires=None, backend=None,
                  options={}, url=None, **kwargs):
         super(CacheBackend, self).__init__(app, **kwargs)
+        self.url = url
 
-        self.options = dict(self.app.conf.CELERY_CACHE_BACKEND_OPTIONS,
+        self.options = dict(self.app.conf.cache_backend_options,
                             **options)
 
-        self.backend = url or backend or self.app.conf.CELERY_CACHE_BACKEND
+        self.backend = url or backend or self.app.conf.cache_backend
         if self.backend:
             self.backend, _, servers = self.backend.partition('://')
             self.servers = servers.rstrip('/').split(';')
@@ -129,14 +129,16 @@ class CacheBackend(KeyValueStoreBackend):
         return self.client.delete(key)
 
     def _apply_chord_incr(self, header, partial_args, group_id, body, **opts):
-        self.client.set(self.get_key_for_chord(group_id), 0, time=86400)
+        self.client.set(self.get_key_for_chord(group_id), 0, time=self.expires)
         return super(CacheBackend, self)._apply_chord_incr(
-            header, partial_args, group_id, body, **opts
-        )
+            header, partial_args, group_id, body, **opts)
 
     def incr(self, key):
         return self.client.incr(key)
 
+    def expire(self, key, value):
+        return self.client.touch(key, value)
+
     @cached_property
     def client(self):
         return self.Client(self.servers, **self.options)
@@ -154,7 +156,6 @@ class CacheBackend(KeyValueStoreBackend):
         """Return the backend as an URI.
 
         This properly handles the case of multiple servers.
-
         """
         servers = ';'.join(self.servers)
         return '{0}://{1}/'.format(self.backend, servers)
