@@ -136,7 +136,8 @@ class AsyncResult(ResultBase):
 
     def get(self, timeout=None, propagate=True, interval=0.5,
             no_ack=True, follow_parents=True, callback=None, on_message=None,
-            on_interval=None, EXCEPTION_STATES=states.EXCEPTION_STATES,
+            on_interval=None, disable_sync_subtasks=True,
+            EXCEPTION_STATES=states.EXCEPTION_STATES,
             PROPAGATE_STATES=states.PROPAGATE_STATES):
         """Wait until task is ready, and return its result.
 
@@ -157,6 +158,9 @@ class AsyncResult(ResultBase):
                 **not be acked**.
             follow_parents (bool): Re-raise any exception raised by
                 parent tasks.
+            disable_sync_subtasks (bool): Disable tasks to wait for sub tasks
+                this is the default configuration. CAUTION do not enable this
+                unless you must.
 
         Raises:
             celery.exceptions.TimeoutError: if `timeout` isn't
@@ -165,7 +169,8 @@ class AsyncResult(ResultBase):
             Exception: If the remote call raised an exception then that
                 exception will be re-raised in the caller process.
         """
-        assert_will_not_block()
+        if disable_sync_subtasks:
+            assert_will_not_block()
         _on_interval = promise()
         if follow_parents and propagate and self.parent:
             on_interval = promise(self._maybe_reraise_parent_error, weak=True)
@@ -268,7 +273,7 @@ class AsyncResult(ResultBase):
                     raise IncompleteStream()
 
     def ready(self):
-        """Return :const:`True` if the task started executing.
+        """Return :const:`True` if the task has executed.
 
         If the task is still running, pending, or is waiting
         for retry then :const:`False` is returned.
@@ -535,7 +540,7 @@ class ResultSet(ResultBase):
     maybe_reraise = maybe_throw  # XXX compat alias.
 
     def waiting(self):
-        """Return true if any of the tasks are incomplate.
+        """Return true if any of the tasks are incomplete.
 
         Returns:
             bool: true if one of the tasks are still
@@ -867,11 +872,11 @@ class GroupResult(ResultSet):
         return self.results
 
     @classmethod
-    def restore(cls, id, backend=None):
+    def restore(cls, id, backend=None, app=None):
         """Restore previously saved group result."""
-        return (
-            backend or (cls.app.backend if cls.app else current_app.backend)
-        ).restore_group(id)
+        app = app or cls.app
+        backend = backend or (app.backend if app else current_app.backend)
+        return backend.restore_group(id)
 
 
 @Thenable.register
